==> issetbv-talos-bundle-v0.2.7-887793.zip: src/IssetBV/PaymentBundle/Entity/SubscriptionTerm.php <==
<?php

declare(strict_types=1);

namespace IssetBV\PaymentBundle\Entity;

use DateInterval;
use DateTime;
use Doctrine\ORM\Mapping as ORM;
use IssetBV\PaymentBundle\Domain\Exception\InvalidPaymentIntervalException;
use IssetBV\PaymentBundle\Domain\Payment;
use IssetBV\PaymentBundle\Domain\Subscription\Subscription;

/**
 * @author Tim Fennis <tim@isset.nl>
 * @ORM\Entity()
 * @ORM\Table(name="subscriptions_terms")
 */
class SubscriptionTerm
{
    /**
     * @var Subscription
     * @ORM\Id()
     * @ORM\ManyToOne(targetEntity="IssetBV\PaymentBundle\Domain\Subscription\Subscription")
     */
    private $subscription;

    /**
     * @var Payment
     * @ORM\Id()
     * @ORM\ManyToOne(targetEntity="IssetBV\PaymentBundle\Domain\Payment")
     */
    private $payment;

    /**
     * @var DateTime
     * @ORM\Column(name="date_time", type="datetime", nullable=false)
     */
    private $dateTime;

    /**
     * @var Interval
     * @ORM\Embedded(class="Interval")
     */
    private $termInterval;

    /**
     * @var bool
     * @ORM\Column(name="activity_override", type="boolean", nullable=false)
     */
    private $override;

    public function __construct(Subscription $subscription, Payment $payment, Interval $termInterval = null, $activityOverride = false)
    {
        $this->subscription = $subscription;
        $this->payment = $payment;
        $this->dateTime = new DateTime();
        $this->termInterval = $termInterval ?: $subscription->getPaymentInterval();
        $this->override = $activityOverride;
    }

    /**
     * @return DateInterval
     */
    public function getTermInterval(): DateInterval
    {
        return $this->termInterval->getDateInterval()->getOrThrow(new InvalidPaymentIntervalException());
    }

    /**
     * @return DateTime
     */
    public function getDateTime(): DateTime
    {
        return $this->dateTime;
    }

    /**
     * @return Subscription
     */
    public function getSubscription(): Subscription
    {
        return $this->subscription;
    }

    /**
     * @return Payment
     */
    public function getPayment(): Payment
    {
        return $this->payment;
    }

    public function isOverrideEnabled(): bool
    {
        return $this->override;
    }

    /**
     * @return bool
     */
    public function isActive(): bool
    {
        $endOfThisTerm = clone $this->dateTime;
        $endOfThisTerm->add($this->getTermInterval());

        return (new DateTime())->getTimestamp() < $endOfThisTerm->getTimestamp();
    }
}

==> issetbv-talos-bundle-v0.2.11-444698.zip: src/IssetBV/PaymentBundle/Entity/SubscriptionTerm.php <==
<?php

declare(strict_types=1);

namespace IssetBV\PaymentBundle\Entity;

use DateInterval;
use DateTime;
use Doctrine\ORM\Mapping as ORM;
use IssetBV\PaymentBundle\Domain\Exception\InvalidPaymentIntervalException;
use IssetBV\PaymentBundle\Domain\Payment;
use IssetBV\PaymentBundle\Domain\Subscription\Subscription;

/**
 * @author Tim Fennis <tim@isset.nl>
 * @ORM\Entity()
 * @ORM\Table(name="subscriptions_terms")
 */
class SubscriptionTerm
{
    /**
     * @var Subscription
     * @ORM\Id()
     * @ORM\ManyToOne(targetEntity="IssetBV\PaymentBundle\Domain\Subscription\Subscription")
     */
    private $subscription;

    /**
     * @var Payment
     * @ORM\Id()
     * @ORM\ManyToOne(targetEntity="IssetBV\PaymentBundle\Domain\Payment")
     */
    private $payment;

    /**
     * @var DateTime
     * @ORM\Column(name="date_time", type="datetime", nullable=false)
     */
    private $dateTime;

    /**
     * @var Interval
     * @ORM\Embedded(class="Interval")
     */
    private $termInterval;

    /**
     * @var bool
     * @ORM\Column(name="activity_override", type="boolean", nullable=false)
     */
    private $override;

    public function __construct(Subscription $subscription, Payment $payment, Interval $termInterval = null, $activityOverride = false)
    {
        $this->subscription = $subscription;
        $this->payment = $payment;
        $this->dateTime = $subscription->getStartDate();
        $this->termInterval = $termInterval ?: $subscription->getPaymentInterval();
        $this->override = $activityOverride;
    }

    /**
     * @return DateInterval
     */
    public function getTermInterval(): DateInterval
    {
        return $this->termInterval->getDateInterval()->getOrThrow(new InvalidPaymentIntervalException());
    }

    /**
     * @return DateTime
     */
    public function getDateTime(): DateTime
    {
        return $this->dateTime;
    }

    /**
     * @return Subscription
     */
    public function getSubscription(): Subscription
    {
        return $this->subscription;
    }

    /**
     * @return Payment
     */
    public function getPayment(): Payment
    {
        return $this->payment;
    }

    public function isOverrideEnabled(): bool
    {
        return $this->override;
    }

    /**
     * @return bool
     */
    public function isActive(): bool
    {
        $endOfThisTerm = clone $this->dateTime;
        $endOfThisTerm->add($this->getTermInterval());

        return (new DateTime())->getTimestamp() < $endOfThisTerm->getTimestamp();
    }
}
